Learn Web Scraping
::::::::::::::::::
 
..  Copyright (C)  Brad Miller, David Ranum
    Permission is granted to copy, distribute and/or modify this document
    under the terms of the GNU Free Documentation License, Version 1.3 or
    any later version published by the Free Software Foundation; with
    Invariant Sections being Forward, Prefaces, and Contributor List,
    no Front-Cover Texts, and no Back-Cover Texts.  A copy of the license
    is included in the section entitled "GNU Free Documentation License".


.. image:: _static/web_crawler.png
    :scale: 20%
    :align: center
    :alt: A robot looking through a magnifying glass


The internet is full of information people would like to collect. Copying and pasting it would take forever! In this ebook, we'll explore an easier way.

 *Web scraping* is the process of getting information from web pages with code.

.. admonition:: During this lesson, you will learn code plans used by *real professionals*.

   These plans represent the most common patterns in web scraping with the BeautifulSoup library. The plans in this ebook were created after an anaylsis of 100 web scraping files from `Github <https://github.com/search?l=Python&q=BeautifulSoup%28&type=Code>`_, as well as two interviews with people who use web scraping in their jobs.


.. toctree::
   :maxdepth: 1

   example1.rst
   example2.rst
   plan2.rst
   plan3.rst
   plan4.rst
   plan5.rst
   plan9.rst
   plan10.rst
   activity-writing-1.rst
   activity-writing-2.rst
   activity-writing-3.rst
   activity-debugging.rst
   activity-explaining.rst
   downloads.rst
   Exercises.rst
   mixedupcode.rst
   writecode.rst
